@@ -31,7 +31,9 @@ GeanyData *geany_data;
 PLUGIN_VERSION_CHECK(224)
 
 PLUGIN_SET_TRANSLATABLE_INFO(LOCALEDIR, GETTEXT_PACKAGE, _("Scope Debugger"),
-	_("Relatively simple GDB front-end."), "0.94",
+	_("Relatively simple GDB front-end."
+	  "\nThis plugin currently has no maintainer. Would you like to help "
+	  "by contributing to this plugin?"), "0.94",
 	"Dimitar Toshkov Zhekov <dimitar.zhekov@gmail.com>")
 
 /* Keybinding(s) */
@@ -87,7 +89,7 @@ static void on_scope_reset_markers(G_GNUC_UNUSED const MenuItem *menu_item)
 
 static void on_scope_cleanup_files(G_GNUC_UNUSED const MenuItem *menu_item)
 {
-	guint i;
+	guint i = 0;
 
 	foreach_document(i)
 	{
@@ -313,7 +315,7 @@ static void on_document_open(G_GNUC_UNUSED GObject *obj, GeanyDocument *doc,
 
 static gboolean settings_saved(gpointer gdata)
 {
-	guint i;
+	guint i = 0;
 
 	foreach_document(i)
 	{
@@ -332,7 +334,7 @@ static gboolean settings_saved(gpointer gdata)
 
 static void schedule_settings_saved(gboolean conterm)
 {
-	guint i;
+	guint i = 0;
 
 	plugin_idle_add(geany_plugin, settings_saved, GINT_TO_POINTER(conterm));
 
@@ -524,10 +526,27 @@ void configure_panel(void)
 	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(debug_panel), pref_panel_tab_pos);
 }
 
+static gchar *get_data_dir_path(const gchar *filename)
+{
+	gchar *prefix = NULL;
+	gchar *path;
+
+#ifdef G_OS_WIN32
+	prefix = g_win32_get_package_installation_directory_of_module(NULL);
+#elif defined(__APPLE__)
+	if (g_getenv("GEANY_PLUGINS_SHARE_PATH"))
+		return g_build_filename(g_getenv("GEANY_PLUGINS_SHARE_PATH"), 
+								PLUGIN, filename, NULL);
+#endif
+	path = g_build_filename(prefix ? prefix : "", PLUGINDATADIR, filename, NULL);
+	g_free(prefix);
+	return path;
+}
+
 void plugin_init(G_GNUC_UNUSED GeanyData *gdata)
 {
 	GeanyKeyGroup *scope_key_group;
-	char *gladefile = g_build_filename(PLUGINDATADIR, "scope.glade", NULL);
+	char *gladefile = get_data_dir_path("scope.glade");
 	GError *gerror = NULL;
 	GtkWidget *menubar1 = ui_lookup_widget(geany->main_widgets->window, "menubar1");
 	guint item;
